@@ -386,6 +386,14 @@ The thread helper utils
 
 The administrative service
 
+=item Sys::Virt::Error::FROM_LOGGING
+
+The logging service
+
+=item Sys::Virt::Error::FROM_XENXL
+
+The Xen XL driver
+
 =back
 
 =head2 ERROR CODE CONSTANTS
